# unblob

unblob is an _accurate, fast, and easy-to-use_ **extraction suite**. It parses
unknown binary blobs for more than 30 different _archive, compression, and
file-system formats_, **extracts** their **content recursively**, and **carves**
out **unknown chunks** that have not been accounted for.

Unblob is _free to use_, licensed with the _MIT license_. It has a
Command Line Interface and can be used as a Python library.  
This turns unblob into the perfect companion for extracting, **analyzing**,
and **reverse engineering firmware images**.

See more at https://unblob.org.

## Demo

![](docs/demo.svg)
